==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/AllocNode.h <==
// public class soot.jimple.spark.pag.AllocNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5773deea6ecc5e2a soot_jimple_spark_pag_AllocNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node

// header file dependencies
// @dep_header soot_jimple_spark_pag_Node

#include "soot/jimple/spark/pag/Node.h"

#ifndef _JC_soot_jimple_spark_pag_AllocNode_H_
#define _JC_soot_jimple_spark_pag_AllocNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_AllocDotField$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_AllocNode$sub_refs	_jc_soot_jimple_spark_pag_AllocNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs	_jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_AllocNode$refs	_jc_soot_jimple_spark_pag_AllocNode$refs;
typedef struct _jc_soot_jimple_spark_pag_AllocNode$nonrefs	_jc_soot_jimple_spark_pag_AllocNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_AllocNode$object	_jc_soot_jimple_spark_pag_AllocNode$object;

typedef const struct _jc_soot_jimple_spark_pag_AllocNode$vmethods	_jc_soot_jimple_spark_pag_AllocNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_AllocNode$vtable	_jc_soot_jimple_spark_pag_AllocNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_AllocNode$vtype	_jc_soot_jimple_spark_pag_AllocNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_AllocNode$method$_init$41b3d87c50ccf35a(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_java_lang_Object$object *, struct _jc_soot_Type$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_pag_AllocNode$method$addField$42d221e7e96b76ab(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *, struct _jc_object *);
extern struct _jc_soot_jimple_spark_pag_AllocDotField$object *_jc_soot_jimple_spark_pag_AllocNode$method$dot$80c8fe7746d247b9(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_spark_pag_AllocNode$method$getAllFieldRefs$37f02f96da2e8cf2(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
extern struct _jc_object *_jc_soot_jimple_spark_pag_AllocNode$method$getFields$9952fcffcaf01724(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_spark_pag_AllocNode$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_spark_pag_AllocNode$method$getNewExpr$5973d040c5a73f9f(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_AllocNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$addField$42d221e7e96b76ab;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$dot$80c8fe7746d247b9;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$getAllFieldRefs$37f02f96da2e8cf2;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$getFields$9952fcffcaf01724;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$getNewExpr$5973d040c5a73f9f;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_AllocNode$vmethods {
	void	(*addField$42d221e7e96b76ab)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *, struct _jc_object *);
	struct _jc_soot_jimple_spark_pag_AllocDotField$object	*(*dot$80c8fe7746d247b9)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_object *);
	struct _jc_object	*(*getAllFieldRefs$37f02f96da2e8cf2)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
	struct _jc_object	*(*getFields$9952fcffcaf01724)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
	struct _jc_java_lang_Object$object	*(*getNewExpr$5973d040c5a73f9f)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_AllocNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_AllocNode$vmethods	soot_jimple_spark_pag_AllocNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_AllocNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_AllocNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_AllocNode$sub_refs {
	struct _jc_java_lang_Object$object	*newExpr;
	struct _jc_object	*fields;
	struct _jc_soot_SootMethod$object	*method;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_AllocNode$refs {
    _jc_soot_jimple_spark_pag_AllocNode$sub_refs	soot_jimple_spark_pag_AllocNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_AllocNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs	soot_jimple_spark_pag_AllocNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_AllocNode$object {
	_jc_soot_jimple_spark_pag_AllocNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_AllocNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_AllocNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_AllocNode$vtype _jc_soot_jimple_spark_pag_AllocNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_AllocNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_AllocNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_AllocNode_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/AllocNode.h <==
// public class soot.jimple.spark.pag.AllocNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5773deea6ecc5e2a soot_jimple_spark_pag_AllocNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node

// header file dependencies
// @dep_header soot_jimple_spark_pag_Node

#include "soot/jimple/spark/pag/Node.h"

#ifndef _JC_soot_jimple_spark_pag_AllocNode_H_
#define _JC_soot_jimple_spark_pag_AllocNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_AllocDotField$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_AllocNode$sub_refs	_jc_soot_jimple_spark_pag_AllocNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs	_jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_AllocNode$refs	_jc_soot_jimple_spark_pag_AllocNode$refs;
typedef struct _jc_soot_jimple_spark_pag_AllocNode$nonrefs	_jc_soot_jimple_spark_pag_AllocNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_AllocNode$object	_jc_soot_jimple_spark_pag_AllocNode$object;

typedef const struct _jc_soot_jimple_spark_pag_AllocNode$vmethods	_jc_soot_jimple_spark_pag_AllocNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_AllocNode$vtable	_jc_soot_jimple_spark_pag_AllocNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_AllocNode$vtype	_jc_soot_jimple_spark_pag_AllocNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_AllocNode$method$_init$41b3d87c50ccf35a(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_java_lang_Object$object *, struct _jc_soot_Type$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_pag_AllocNode$method$addField$42d221e7e96b76ab(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_spark_pag_AllocDotField$object *_jc_soot_jimple_spark_pag_AllocNode$method$dot$80c8fe7746d247b9(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_spark_pag_AllocNode$method$getAllFieldRefs$37f02f96da2e8cf2(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_spark_pag_AllocNode$method$getFields$9952fcffcaf01724(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_spark_pag_AllocNode$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_spark_pag_AllocNode$method$getNewExpr$5973d040c5a73f9f(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_AllocNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$addField$42d221e7e96b76ab;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$dot$80c8fe7746d247b9;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$getAllFieldRefs$37f02f96da2e8cf2;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$getFields$9952fcffcaf01724;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$getNewExpr$5973d040c5a73f9f;
extern _jc_method _jc_soot_jimple_spark_pag_AllocNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_AllocNode$vmethods {
	void	(*addField$42d221e7e96b76ab)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_spark_pag_AllocDotField$object	*(*dot$80c8fe7746d247b9)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAllFieldRefs$37f02f96da2e8cf2)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getFields$9952fcffcaf01724)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getNewExpr$5973d040c5a73f9f)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_AllocNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_AllocNode$vmethods	soot_jimple_spark_pag_AllocNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_AllocNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_AllocNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_AllocNode$sub_refs {
	struct _jc_java_lang_Object$object	*newExpr;
	struct _jc_object	*fields;
	struct _jc_soot_SootMethod$object	*method;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_AllocNode$refs {
    _jc_soot_jimple_spark_pag_AllocNode$sub_refs	soot_jimple_spark_pag_AllocNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_AllocNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs	soot_jimple_spark_pag_AllocNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_AllocNode$object {
	_jc_soot_jimple_spark_pag_AllocNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_AllocNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_AllocNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_AllocNode$vtype _jc_soot_jimple_spark_pag_AllocNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_AllocNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_AllocNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_AllocNode_H_ */
